Method: OptparsePlus::ProcessStatus#initialize
- Defined in:
- lib/optparse_plus/process_status.rb
#initialize(status, expected) ⇒ ProcessStatus
Create the ProcessStatus with the given status.
- status
-
if this responds to #exitstatus, that method is used to extract the exit code. If it’s and Int, that is used as the exit code. Otherwise, it’s truthiness is used: 0 for truthy, 1 for falsey.
- expected
-
an Int or Array of Int representing the expected exit status, other than zero, that represent “success”.
18 19 20 21 |
# File 'lib/optparse_plus/process_status.rb', line 18 def initialize(status,expected) @exitstatus = derive_exitstatus(status) @success = ([0] + Array(expected)).include?(@exitstatus) end |